==> rhit-1.7.2.tar.gz: rhit-1.7.2/website/docs/community.md <==

**Rhit** is developed by [Denys Séguret](https://twitter.com/DenysSeguret), also known as [Canop](https://github.com/Canop) or [dystroy](https://dystroy.org).

# Sponsorship

**Rhit** is free for all uses.

If it helps you make money, consider helping me find time to add features and to develop new free open-source software.

<div class=sponsorship>
<script src="https://liberapay.com/dystroy/widgets/button.js"></script>
<noscript><a href="https://liberapay.com/dystroy/donate"><img alt="Donate using Liberapay" src="https://liberapay.com/assets/widgets/donate.svg"></a></noscript>

<iframe src="https://github.com/sponsors/Canop/button" title="Sponsor Canop" height="35" width="114" style="border: 0; border-radius: 6px;"></iframe>
</div>


# Discuss Rhit in a chat room

The best place to chat about rhit, to talk about features or bugs, is the Miaou chat.

* [Rust & Rhit room on Miaou](https://miaou.dystroy.org/3490?rust)
* [French Programers room on Miaou](https://miaou.dystroy.org/3)

# Issues

We use [GitHub's issue manager](https://github.com/Canop/rhit/issues).

Before posting a new issue, check your problem hasn't already been raised and in case of doubt **please come first discuss it on the chat**.

## Log

When something looks like a bug, we need both to know the exact configuration (OS, terminal program, mainly) and to have the log. The log can be obtained this way:

1. execute rhit with `RHIT_LOG=debug rhit`
1. go to the chat (or the GitHub issue if you already made one) and paste the content of the `rhit.log` file

==> rhit-2.0.2.tar.gz: rhit-2.0.2/website/docs/community.md <==

**Rhit** is developed by [Denys Séguret](https://twitter.com/DenysSeguret), also known as [Canop](https://github.com/Canop) or [dystroy](https://dystroy.org).

# Sponsorship

**Rhit** is free for all uses.

If it helps you make money, consider helping me find time to add features and to develop new free open-source software.

<div class=sponsorship>
<!--
<script src="https://liberapay.com/dystroy/widgets/button.js"></script>
<noscript><a href="https://liberapay.com/dystroy/donate"><img alt="Donate using Liberapay" src="https://liberapay.com/assets/widgets/donate.svg"></a></noscript>
-->

<iframe src="https://github.com/sponsors/Canop/button" title="Sponsor Canop" height="35" width="114" style="border: 0; border-radius: 6px;"></iframe>
</div>


# Discuss Rhit in a chat room

The best place to chat about rhit, to talk about features or bugs, is the Miaou chat.

* [Rust & Rhit room on Miaou](https://miaou.dystroy.org/3490?rust)
* [French Programmers room on Miaou](https://miaou.dystroy.org/3)

# Issues

We use [GitHub's issue manager](https://github.com/Canop/rhit/issues).

Before posting a new issue, check your problem hasn't already been raised and in case of doubt **please come first discuss it on the chat**.

## Log

When something looks like a bug, we need both to know the exact configuration (OS, terminal program, mainly) and to have the log. The log can be obtained this way:

1. execute rhit with `RHIT_LOG=debug rhit`
1. go to the chat (or the GitHub issue if you already made one) and paste the content of the `rhit.log` file
